@@ -100,10 +100,16 @@ class ContractMethod:
         print("=======end event report ========")
 
     def handle_ret(self, r: dict) -> any:
-        if r['result']['code'] == 'CONTRACT_VALIDATE_ERROR':
-            raise KeyError('Cannot get the result from the contract value. msg:{}'.format(r['result']['message']))
+        ok, key, message = self.transaction_builder.handle_ret(r)
+
+        if ok:
+            print("=======debug request result {}".format(key))
+            print(r)
+            print(message)
+            print("=======end event report ========")
+            return self.parse_output(message)
         else:
-            return self.parse_output(r)
+            raise KeyError('Request returns Error - {} msg:{} txt:{}'.format(key, message, self.parse_output(message)))
 
     def parse_output(self, raw: any) -> any:
         if type(raw) is bytes:
@@ -144,8 +150,6 @@ class ContractMethod:
         else:
             raise TypeError("wrong number of arguments, require {}".format(len(self.inputs)))
 
-
-
         paramdict = dict(
             contract_address=self.contract_address,
             function_selector=self.function_signature,
