@@ -8,6 +8,8 @@
 # Here you can specify links to sites of different types.
 # The default is verified links.
 # If you do not know what links are used for, it is recommended not to change
+from typing import Tuple
+
 DEFAULT_NODES = {
     'full_node': 'https://api.trongrid.io',
     'solidity_node': 'https://api.trongrid.io',
@@ -48,6 +50,30 @@ ALL = {
     "tronex": CONF_TRONEX
 }
 
+RES_CODE = dict(
+    SUCCESS=0,
+    SIGERROR=1,
+    CONTRACT_VALIDATE_ERROR=2,
+    CONTRACT_EXE_ERROR=3,
+    BANDWITH_ERROR=4,
+    DUP_TRANSACTION_ERROR=5,
+    TAPOS_ERROR=6,
+    TOO_BIG_TRANSACTION_ERROR=7,
+    TRANSACTION_EXPIRATION_ERROR=8,
+    SERVER_BUSY=9,
+    NO_CONNECTION=10,
+    NOT_ENOUGH_EFFECTIVE_CONNECTION=11,
+    OTHER_ERROR=20
+)
+
 
 def conf_for_name(name: str) -> dict:
     return ALL.get(name, None)
+
+
+def handle_res(r: dict) -> Tuple[bool, str, str]:
+    resultcode = r['result']['code']
+    if RES_CODE.get(resultcode) > 0:
+        return False, resultcode, r['result']['message']
+    else:
+        return True, resultcode, r['result']['message']
