@@ -22,6 +22,7 @@ from trx_utils import (
 )
 
 from tronpytool.common.validation import is_valid_url
+from tronpytool.constants import handle_res
 from tronpytool.exceptions import (
     InvalidTronError,
     TronError,
@@ -617,6 +618,7 @@ class TransactionBuilder(object):
         fee_limit = kv.setdefault('fee_limit', 1000000000)
         token_value = kv.setdefault('token_value', 0)
         token_id = kv.setdefault('token_id', 0)
+        parameters = kv.setdefault('parameters', [])
 
         if not is_integer(token_value) or token_value < 0:
             raise ValueError('Invalid options.tokenValue provided')
@@ -639,10 +641,9 @@ class TransactionBuilder(object):
         """remove all the spaces"""
         function_selector = function_selector.replace('/\s*/g', '')
 
-        if hasattr(kv, "parameters") and len(kv['parameters']) > 0:
+        if len(parameters) > 0:
             types = []
             values = []
-            parameters = kv['parameters']
             for abi in parameters:
                 if 'type' not in abi or not is_string(abi['type']):
                     raise ValueError('Invalid parameter type provided: ' + abi['type'])
@@ -659,10 +660,7 @@ class TransactionBuilder(object):
                 print(ex)
 
         else:
-            parameters = []
-
-        print("==checking")
-        print(kv)
+            parameters = ''
 
         data = {
             'contract_address': self.tron.toHex(text=contract_address),
@@ -672,6 +670,11 @@ class TransactionBuilder(object):
             'call_value': int(call_value),
             'parameter': parameters
         }
+        print("==checking")
+        print(kv)
+
+        #if parameters is '':
+        #    data.pop('parameter')
 
         if token_value:
             data['call_token_value'] = int(token_value)
@@ -684,6 +687,9 @@ class TransactionBuilder(object):
 
         return self.tron.manager.request('/wallet/triggersmartcontract', data)
 
+    def handle_ret(self, r: dict) -> any:
+        return handle_res(r)
+
     def create_trx_exchange(self,
                             token_name: str,
                             token_balance: int,
